Module drawing

Module drawing 

All Points Addressable (APA) mode drawing library.

This provies wrapper of drawing.h routines from GBDK.

Caution

The GameBoy graphics hardware is not well suited to frame-buffer style graphics such as the kind provided in drawing. Due to that, most drawing functions will slow.

When possible it’s much faster and more efficient to work will the tiles and tiles maps that the GameBoy hardware is built around.

We do not recommend using this function in Rust-GB.

Safety

Due to the complex side effect of APA mode, drawing functions can cause unexpected issues. Most of expected issues are wrapped in Rust-GB, but it is your own risk to use this module.

Structs

DrawingStream
Byte drawing stream of GameBoy.
DrawingStyle
The style in how drawing functions work.

Enums

DmgColor
Color set of original GameBoy.
DrawingMode
Drawing mode of drawing functions.

Constants

SCREEN_HEIGHT
SCREEN_WIDTH
TILE_HEIGHT
TILE_WIDTH