GbStream

Struct GbStream 

pub struct GbStream { /* private fields */ }
Byte print stream of GameBoy.

Currently, GbStream prints bytes one by one using GBDK’s putchar function. In the long run, it is likely to change to RustGB own implementation.

Optionally, GbStream can have font and color.

Examples

use core::fmt::Write;

let mut w = GbStream::new();
write!(w, "Hello, World!");

Implementations

Source

impl GbStream

pub fn stream() -> Self

Get GameBoy console stream.

pub fn clear()

Clear GameBoy console.

pub fn cursor(x: u8, y: u8)

Set cursor of GbStream.

Panics

Panics if coordinate parameter out of bounds.

Examples
cursor(0, 1); //prints to second line.
print!("Hello, cursor!");
pub fn write_byte(&mut self, b: u8) -> Result<(), Error>

Writes a byte into this writer, returning whether the write succeeded.

write_char assumes that the input is valid Unicode character. However, GBDK maps one byte to one character or symbol.

Therefore, write_byte is recommended when you want to print one character to the GameBoy.

Errors

This function will return an instance of Error on error.