Joypad

Struct Joypad 

pub struct Joypad(/* private fields */);
Joypad input struct.

Joypad (Buttons and D-Pad key) can be checked by writing and reading the JOYP register. (0xFF00) This struct makes it easy and safe.

The most recommended use is to receive key information on all keys at once using the Joypad::read() function for once in each frame, and then check the key press using a method.

Examples

let key = Joypad::read();
if key.a() {
    println!("A pressed!");
}
if key.b() {
    println!("B pressed!");
}

Implementations

Source

impl Joypad

pub fn read() -> Self

Get all buttons status.

Internally, write and read twice in the JOYP register, and returns Joypad tuple struct with bitwise OR of JoypadKey values.

pub fn a(&self) -> bool

Check if A button is pressed.

pub fn b(&self) -> bool

Check if B button is pressed.

pub fn select(&self) -> bool

Check if Select button is pressed.

pub fn start(&self) -> bool

Check if Start button is pressed.

pub fn right(&self) -> bool

Check if Right of d-pad is pressed.

pub fn left(&self) -> bool

Check if Left of d-pad is pressed.

pub fn up(&self) -> bool

Check if Up of d-pad is pressed.

pub fn down(&self) -> bool

Check if Down of d-pad is pressed.

pub fn wait_until_press() -> Self

Waits until any key pressed.

pub fn wait_until_release()

Waits until all key released.