macro_rules! print {
($($arg:tt)*) => { ... };
}Expand description
Prints to the GameBoy screen.
If you’ve ever used print! macro in std, you’ll familiar with this.
Equivalent to the println! macro except that newline is not printed at
the end of the message.
The print! macro will work with default GbStream. So, texts that
written with your custom GbStream will removed.
Warning
Since the compiled fmt function is very large, care must be taken not to exceed the ROM capacity of GameBoy.
In addition, compilation will fail if formatting is attempted for floating points
and integers over 32bits. Attempts to use Debug trait ({:?}) will also fail.
Examples
print!("Hello, ");
print!("Rust-GB!\n");
print!("Answer!: {}", 42);