All Points Addressable (APA) mode drawing library.
This provies wrapper of drawing.h routines from GBDK.
Caution
The GameBoy graphics hardware is not well suited to frame-buffer style
graphics such as the kind provided in drawing. Due to that, most drawing
functions will slow.
When possible it’s much faster and more efficient to work will the tiles and tiles maps that the GameBoy hardware is built around.
We do not recommend using this function in Rust-GB.
Safety
Due to the complex side effect of APA mode, drawing functions can cause
unexpected issues. Most of expected issues are wrapped in Rust-GB, but it is
your own risk to use this module.
Structs
- Drawing
Stream - Byte drawing stream of GameBoy.
- Drawing
Style - The style in how
drawingfunctions work.
Enums
- DmgColor
- Color set of original GameBoy.
- Drawing
Mode - Drawing mode of
drawingfunctions.