DrawingStream

Struct DrawingStream 

pub struct DrawingStream { /* private fields */ }
Byte drawing stream of GameBoy.

It simillars with crate::io::GbStream. But there are some significant differences.

  1. DrawingStream uses APA mode drawing library of GBDK. this causes many side effects, For example, if you try to use DrawingStream inside a VBL interrupt, it will have unexpected result. For more detail, please refer GBDK Docs

  2. Unable to change line with \n, this means, when you want to make a new line, you should use the DrawingStream::cursor function.

  3. DrawingStream can also draw shapes in addition to texts.

Examples

let mut s = unsafe {DrawingStream::new()}; // prints to second line.
write!(s, "Hello, APA!");

Implementations

Source

impl DrawingStream

pub unsafe fn new() -> Self

Creates new DrawingStream.

Enable APA mode to draw texts.

Safety

This will break crate::io::GbStream.

After this function, you cannot use GbStream dependent functions such as println!.

pub fn set_style(&self, style: DrawingStyle)

Apply drawing style.

Internally, call color function of GBDK.

pub fn cursor(&self, x: u8, y: u8)

Set cursor of DrawingStream.

Panics

Panics if coordinate parameter out of bounds.

Safety

Because of the bound check, it is guaranteed to move the cursor to a valid range.

Examples
let mut s = unsafe {DrawingStream::new()};
DrawingStream::cursor(0, 1); //prints to second line.
write!(s, "Hello, Cursor!");
pub fn draw_point(&self, (x, y): (u8, u8))

Draw a point to screen.

Panics

Panics if coordinates out of bounds.

pub fn draw_line(&self, (x1, y1): (u8, u8), (x2, y2): (u8, u8))

Draw a line to screen.

Panics

Panics if coordinates out of bounds.

pub fn draw_box(&self, (x1, y1): (u8, u8), (x2, y2): (u8, u8), fill: bool)

Draw a box to screen.

Panics

Panics if coordinates out of bounds.

pub fn draw_circle(&self, (x, y): (u8, u8), radius: u8, fill: bool)

Draw a circle to screen.

Panics

Panics if coordinates out of bounds.

pub fn write_byte(&mut self, b: u8) -> Result<(), Error>

Writes a byte into this writer, returning whether the write succeeded.

write_char assumes that the input is valid Unicode character. However, GBDK maps one byte to one character or symbol.

Therefore, write_byte is recommended when you want to print one character to the GameBoy.

Errors

This function will return an instance of Error on error.